#######################################################################
#
#    3d2dSkinSwitch Plugin for Dreambox-Enigma2
#    Coded by Vali (c)2011
#    Support: www.dreambox.tools
#
#  This plugin is licensed under the Creative Commons 
#  Attribution-NonCommercial-ShareAlike 3.0 Unported License.
#  To view a copy of this license, visit http://creativecommons.org/licenses/by-nc-sa/3.0/
#  or send a letter to Creative Commons, 559 Nathan Abbott Way, Stanford, California 94305, USA.
#
#  Alternatively, this plugin may be distributed and executed on hardware which
#  is licensed by Dream Multimedia GmbH.
#
#
#  This plugin is NOT free software. It is open source, you are allowed to
#  modify it (if you keep the license), but it may not be commercially 
#  distributed other than under the conditions noted above.
#
#
#######################################################################



from Screens.Screen import Screen
from Plugins.Plugin import PluginDescriptor
from Components.ActionMap import ActionMap
from Components.ServiceEventTracker import ServiceEventTracker
from enigma import gMainDC, getDesktop, eSize, iPlayableService, iServiceInformation, eServiceCenter, eServiceReference
from ServiceReference import ServiceReference

def Plugins(**kwargs):
	return [PluginDescriptor(where = [PluginDescriptor.WHERE_SESSIONSTART], fnc=autostart)]

def autostart(session, **kwargs):
	Auto3DSkinSwitch(session)

class Auto3DSkinSwitch(Screen):

	def __init__(self, session):
		self.session = session
		Screen.__init__(self, session)
		self.__event_tracker = ServiceEventTracker(screen = self, eventmap =
			{
				iPlayableService.evUpdatedInfo: self.__evUpdatedInfo,
				iPlayableService.evStart: self.__evStart
			})

		self.newService = False
		self.originalXRes = getDesktop(0).size().width()
		self.originalYRes = getDesktop(0).size().height()

	def __evStart(self):
		self.newService = True

	def __evUpdatedInfo(self):
		if self.newService and self.session.nav.getCurrentlyPlayingServiceReference():
			self.newService = False
			ref = self.session.nav.getCurrentService() 
			serviceRef = self.session.nav.getCurrentlyPlayingServiceReference()
			if serviceRef.getPath():
				serviceHandler = eServiceCenter.getInstance()
				r = eServiceReference(ref.info().getInfoString(iServiceInformation.sServiceref))
				info = serviceHandler.info(r)
				if info:
					name = ServiceReference(info.getInfoString(r, iServiceInformation.sServiceref)).getServiceName().replace('\xc2\x86', '').replace('\xc2\x87', '')
				else:
					name = ""
			else:
				name =  ServiceReference(ref.info().getInfoString(iServiceInformation.sServiceref)).getServiceName().replace('\xc2\x86', '').replace('\xc2\x87', '')
			if name.lower().endswith("3d"): 
				xres = self.originalXRes*2
			else:
				xres = self.originalXRes
			desktop = getDesktop(0)
			if xres != desktop.size().width():
				gMainDC.getInstance().setResolution(xres, self.originalYRes)
				desktop.resize(eSize(xres, self.originalYRes))

